==> remotecontrol-1.0.zip: remotecontrol-1.0/src/lib/Global.php <==
<?php

//        # Copyright (C) 2012-2013 GNU remotecontrol authors.
//        #
//        # This program is free software: you can redistribute it and/or modify
//        # it under the terms of the GNU Affero General Public License as
//        # published by the Free Software Foundation, either version 3 of the
//        # License, or (at your option) any later version.
//        #
//        # This program is distributed in the hope that it will be useful,
//        # but WITHOUT ANY WARRANTY; without even the implied warranty of
//        # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        # GNU Affero General Public License for more details.
//        #
//        # You should have received a copy of the GNU Affero General Public License
//        # along with this program.  If not, see <http://www.gnu.org/licenses/>.

        require_once('CommandType.php');
	require_once('Common.php');
	require_once('DatabaseException.php');
	require_once('ErrorLog.php');
	require_once('IPThermostat.php');
	require_once('IPThermostatCollection.php');
	require_once('IPThermostatObject.php');
	require_once('IPThermostatObjectCollection.php');
        require_once('Language.php');
        require_once('LanguageCollection.php');
	require_once('MySqlCommand.php');
	require_once('MySqlDataAccess.php');
        require_once('Resource.php');
        require_once('ResourceCollection.php');
	require_once('TimeZoneOffset.php');
        require_once('TimeZoneOffsetCollection.php');
	require_once('TransactionLog.php');
	require_once('TransactionLogRecord.php');
	require_once('TransactionLogRecordCollection.php');
	require_once('User.php');
	require_once('UserCollection.php');
        
        if (!isset($_SESSION))
        {
            session_start();
        }

?>

==> remotecontrol-1.1.zip: remotecontrol-1.1/src/lib/Global.php <==
<?php

//        # Copyright (C) 2012-2013 GNU remotecontrol authors.
//        #
//        # This program is free software: you can redistribute it and/or modify
//        # it under the terms of the GNU Affero General Public License as
//        # published by the Free Software Foundation, either version 3 of the
//        # License, or (at your option) any later version.
//        #
//        # This program is distributed in the hope that it will be useful,
//        # but WITHOUT ANY WARRANTY; without even the implied warranty of
//        # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//        # GNU Affero General Public License for more details.
//        #
//        # You should have received a copy of the GNU Affero General Public License
//        # along with this program.  If not, see <http://www.gnu.org/licenses/>.

	require_once('CommandType.php');
	require_once('Common.php');
	require_once('DatabaseException.php');
	require_once('ErrorLog.php');
	require_once('IPThermostat.php');
	require_once('IPThermostatCollection.php');
	require_once('IPThermostatGroup.php');
	require_once('IPThermostatGroupCollection.php');
	require_once('IPThermostatObject.php');
	require_once('IPThermostatObjectCollection.php');
    require_once('Language.php');
    require_once('LanguageCollection.php');
	require_once('MySqlCommand.php');
	require_once('MySqlDataAccess.php');
    require_once('Resource.php');
    require_once('ResourceCollection.php');
	require_once('TimeZoneOffset.php');
    require_once('TimeZoneOffsetCollection.php');
	require_once('TransactionLog.php');
	require_once('TransactionLogRecord.php');
	require_once('TransactionLogRecordCollection.php');
	require_once('User.php');
	require_once('UserCollection.php');
	require_once('SessionHandling.php');
	require_once('Templates.php');
    $sessionHandling = new SessionHandling();
    $templateHandling = new Templates();

?>
